from setuptools import setup

setup(name='yuntools',
      version='0.1',
      description='Taiwan No. 1',
      url='http://github.com/storborg/funniest',
      author='Michael Chen',
      author_email='flyingcircus@example.com',
      license='MIT',
      packages=['yuntools'],
      zip_safe=False)